/* 
 * AndSys 0.3.g.23 Copyright (C) 2012, 2013 Giulio Orru'
 * 
 * Licensed under the MIT license:
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package net.sourceforge.andsys;

import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.view.View;
import android.view.Window;
import android.widget.Button;
import android.widget.ImageButton;
import android.widget.LinearLayout;
import android.widget.TextView;

/*
 * TODO: not well sort Packages List on Change language 
 * TODO: designed for tablets
 */

/**
 * Commons in every Activity
 */
public abstract class Activity extends android.app.Activity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        /*
         * Remove title bar: call requestWindowFeature(... before setContentView(...
         */
        this.requestWindowFeature(Window.FEATURE_NO_TITLE);

    }

    @Override
    protected void onStart() {
        super.onStart();

        /*
         * Header1 Button: change background of selected button
         */

        if (getClass().equals(ActivityInfo.class)) {
            ImageButton header1Info = (ImageButton) findViewById(R.id.header1Info);
            header1Info.setBackgroundResource(R.drawable.orange);
            
        } else if (getClass().equals(ActivityHelpReadme.class)
                || getClass().equals(ActivityHelpFeatures.class)) {
            ImageButton header1Help = (ImageButton) findViewById(R.id.header1Help);
            header1Help.setBackgroundResource(R.drawable.orange);

            /*
             * Header2 Button: change background of selected button
             */
            
            TextView emptyUsefullGetTextAppearence = (TextView) findViewById(R.id.empty_usefull_get_text_appearence);
            if (getClass().equals(ActivityHelpReadme.class)) {
                Button header2HelpReadme = (Button) findViewById(R.id.header2HelpReadme);
                LinearLayout header2Item1Line = (LinearLayout) findViewById(R.id.header2Item1Line);
                header2HelpReadme.setBackgroundResource(R.drawable.shadow);
                header2HelpReadme.setTextColor(emptyUsefullGetTextAppearence.getCurrentTextColor());
                header2Item1Line.setBackgroundResource(R.drawable.celestial);
                
            } else {
                // getClass().equals(ActivityHelpFeatures.class))
                Button header2HelpFeatures = (Button) findViewById(R.id.header2HelpFeatures);
                LinearLayout header2Item2Line = (LinearLayout) findViewById(R.id.header2Item2Line);
                header2HelpFeatures.setBackgroundResource(R.drawable.shadow);
                header2HelpFeatures.setTextColor(emptyUsefullGetTextAppearence
                        .getCurrentTextColor());
                header2Item2Line.setBackgroundResource(R.drawable.celestial);
            }

        } else {
            // (getClass().equals(ActivityPackages.class))
            ImageButton header1Packages = (ImageButton) findViewById(R.id.header1Packages);
            header1Packages.setBackgroundResource(R.drawable.orange);
        }
    }

    /**
     * Action for Header1 Packages Button
     * 
     * @param view
     *            Unused
     */
    public void onClickHeader1Packages(View view) {
        Intent intent = new Intent(this, ActivityPackages.class);
        startActivity(intent);
    }

    /**
     * Action for Header1 Info Button
     * 
     * @param view
     *            Unused
     */
    public void onClickHeader1Info(View view) {
        Intent intent = new Intent(this, ActivityInfo.class);
        startActivity(intent);
    }

    /**
     * Action for Header1 Help Button
     * 
     * @param view
     *            Unused
     */
    public void onClickHeader1Help(View view) {
        onClickHeader2HelpReadme(view);
    }

    /**
     * Action for Header1 Help Button
     * 
     * @param view
     *            Unused
     */
    public void onClickHeader2HelpReadme(View view) {
        Intent intent = new Intent(this, ActivityHelpReadme.class);
        startActivity(intent);
    }

    /**
     * Action for Header2 Help Features
     * 
     * @param view
     *            Unused
     */
    public void onClickHeader2HelpFeatures(View view) {
        Intent intent = new Intent(this, ActivityHelpFeatures.class);
        startActivity(intent);
    }
    
    
    /**
     * Action for Header2 Loading Button
     * 
     * @param view
     *            Unused
     */
       public void onClickHeader2Loading(View view) {
           
           // to: Displaying progress bar when waiting
           final Context context = this.getBaseContext();
           
           // to use in type new Runnable
           final android.app.Activity activity = this;
           
           final ProgressDialog progressDialog = ProgressDialog.show(this,
                   getText(R.string.label_activity_loading),
                   getText(R.string.label_activity_loading_text));
           Handler handler = new Handler();
           handler.postDelayed(new Runnable() {
               @Override
               public void run() {

                   // --- IN BACKGROUND: BEGIN ---

                   // Acquire Packages List (in the global scope) Application
                   Application.packages(context);

                   // Order by.. (in the global scope)
                   Application.packagesSort();
                   
                   
                   // Acquire Device Information
                   Application.device(activity);

                   // increment redirect counter (Activities: Loading -> Packages -> Loading)
                   //Application.redirect++;
                   
                   // --- IN BACKGROUND: END ---

                   // Dismiss the progress dialog
                   progressDialog.dismiss();

                   // Restart the Activity with new Data
                   onStart();
               }

           }, 1000);
       
       }
}
